==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_ActivateEvent.h <==
//----------------------------------------------------------------------------
// wxActivateEvent
// extracted from activevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_ACTIVATEEVENT_H__
#define __CLASS_WX_ACTIVATEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxActivateEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ActivateEvent);

//----------------------------------------------------------------------------
// Object declaration for wxActivateEvent
//----------------------------------------------------------------------------
class Object_wx_ActivateEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_ActivateEvent)
public:
	inline Object_wx_ActivateEvent(wxActivateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_ActivateEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_ActivateEvent(Class *pClass, wxActivateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_ActivateEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxActivateEvent *GetEntity() {
		return dynamic_cast<wxActivateEvent *>(_pEntity);
	}
	inline wxActivateEvent *ReleaseEntity() {
		wxActivateEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxActivateEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_ActivateEvent.h <==
//----------------------------------------------------------------------------
// wxActivateEvent
// extracted from activevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_ACTIVATEEVENT_H__
#define __CLASS_WX_ACTIVATEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxActivateEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ActivateEvent);

//----------------------------------------------------------------------------
// Object declaration for wxActivateEvent
//----------------------------------------------------------------------------
class Object_wx_ActivateEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_ActivateEvent)
public:
	inline Object_wx_ActivateEvent(wxActivateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_ActivateEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_ActivateEvent(Class *pClass, wxActivateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_ActivateEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxActivateEvent *GetEntity() {
		return dynamic_cast<wxActivateEvent *>(_pEntity);
	}
	inline wxActivateEvent *ReleaseEntity() {
		wxActivateEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxActivateEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
